import Layout from './layout'
import Form from './form'
import FormItem from './form-item'
import FormContent from './form-content'
import Button from './button'
import ButtonGroup from './button-group'
// import Table from './table'
import Input from './input'
import InputNumber from './input-number'
import Select from './select'
import Cascader from './cascader'
import TimeSelect from './time-select'
import TimePicker from './time-picker'
import DatePicker from './date-picker'
// import TableColumn from './table-column'
import Pagination from './pagination'
import Drawer from './drawer'
import DictSelect from './dict-select'


const components = [
    Layout,
    Form,
    FormItem,
    FormContent,
    Button,
    ButtonGroup,
    // Table,
    Input,
    InputNumber,
    Select,
    Option,
    Cascader,
    TimeSelect,
    TimePicker,
    DatePicker,
    // TableColumn,
    Pagination,
    Drawer,
    DictSelect,
]

function install(Vue, options = {}) {

    // locale.use(options.locale);
    // locale.i18n(options.i18n);

    components.forEach(component => {
        Vue.component(component.name, component);
    });

    // 分页全局配置
    let pagination = options.pagination || {}

    let paginationOptions = {
        layout: pagination.layout || 'prev, pager, next, sizes, jumper',
        pageSizes: pagination.pageSizes || [10, 20, 50, 100]
    }
    // 表单全局配置
    let form = options.form || {}
    let formOptions = {
        placeholder: false,
        position: true,
        ...form,
    }
    // 二次封装下拉选择框配置
    let dictSelect = options.dictSelect || {}

    let drawer = options.drawer || {}
    let table = options.table || {}
    let tableColumn = options.tableColumn || {}
    let input = options.input || {}
    let select = options.select || {}
    let cascader = options.cascader || {}

    Vue.prototype.$ELEMENT = {
        size: options.size || '',
        zIndex: options.zIndex || 2000,
        dictSelect: dictSelect,
        form: formOptions,
        pagination: {
            background: true,
            ...paginationOptions
        },
        drawer: {
            footer: true,
            showCancelButton: true,
            showConfirmButton: true,
            ...drawer
        },
        table: {
            index: true,
            scroll: true,
            ...table
        },
        tableColumn,
        input,
        select,
        cascader
    };

}

export default {
    install,
    Layout,
    Form,
    FormItem,
    FormContent,
    Button,
    ButtonGroup,
    // Table,
    Input,
    InputNumber,
    Select,
    Option,
    Cascader,
    TimeSelect,
    TimePicker,
    DatePicker,
    Pagination,
    Drawer,
    DictSelect
}
