const fs = require('fs')
const path = require('path')
const baseConfig = require('./webpack.base')
const { merge } = require('webpack-merge')
// 清除构建目录
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const VueLoaderPlugin = require('vue-loader/lib/plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const TerserPlugin = require('terser-webpack-plugin')


const resolve = name => {
    return path.resolve(__dirname, name)
}
const dir = resolve('../packages')
const files = fs.readdirSync(dir)
let modules = {}

files.forEach(name => {
    name = name.replace(/(\.\/|\.js)$/g, '')
    modules[name] = path.join(__dirname, '../packages', name)
})

const config = {
    mode: 'production',
    entry: modules,
    output: {
        path: path.resolve(__dirname, '../lib'),
        filename: '[name].js',
        libraryTarget: 'umd',
        library: 'vue-element-ui-plus',
        libraryExport: 'default'
    },
    externals: {
        vue: {
            root: 'Vue',
            commonjs: 'vue',
            commonjs2: 'vue',
            amd: 'vue'
        }
    },
    optimization: {
        minimize: true,
        minimizer: [
            new TerserPlugin({
                extractComments: false,
                terserOptions: {
                    format: {
                        comments: false,
                    },
                },
            }),
        ],
    },
    plugins: [
        new VueLoaderPlugin(),
        new CleanWebpackPlugin(),
        new MiniCssExtractPlugin({
            filename: '../lib/css/[name].css'
        })
    ]
}

module.exports = merge(config, baseConfig)
